//Source file: ChargePerVolume.java
//Date: September 2004
//Data Session Control Interfaces and Data Types for 3GPP TS 29.198-08 V5.7.0

package org.csapi.jr.se.dsc;

/**
 * Defines the Sequence of Data Elements that specify the time based charging information. The volume is the sum of uplink and downlink transfer data volumes.
 * 
 */
public final class ChargePerVolume implements java.io.Serializable {

    private int initialCharge;
    private int currentChargePerKilobyte;
    private int nextChargePerKilobyte;

    /**
     * Creates a new ChargePerVolume instance.
     */
    public ChargePerVolume () {}

    /**
     * Creates a new ChargePerVolume instance.
     * @param _initialCharge   Initial charge amount (in currency units * 0.0001).
     * @param _currentChargePerKilobyte   Current tariff (in currency units * 0.0001).
     * @param _nextChargePerKilobyte   Next tariff (in currency units * 0.0001) after tariff switch.
Only used in setAdviceOfCharge().
     */
    public ChargePerVolume (int _initialCharge, int _currentChargePerKilobyte, int _nextChargePerKilobyte) {

        this.initialCharge = _initialCharge;
        this.currentChargePerKilobyte = _currentChargePerKilobyte;
        this.nextChargePerKilobyte = _nextChargePerKilobyte;
    }

    /**
     * This method returns a initialCharge.
     * 
     * @return a int value
     */
    public int getInitialCharge() {
        return initialCharge;
    }

    /**
     * This method returns a currentChargePerKilobyte.
     * 
     * @return a int value
     */
    public int getCurrentChargePerKilobyte() {
        return currentChargePerKilobyte;
    }

    /**
     * This method returns a nextChargePerKilobyte.
     * 
     * @return a int value
     */
    public int getNextChargePerKilobyte() {
        return nextChargePerKilobyte;
    }


    /**
     * This method sets a initialCharge.
     */ 
    public void setInitialCharge(int initialCharge) {
        this.initialCharge = initialCharge;
    }

    /**
     * This method sets a currentChargePerKilobyte.
     */ 
    public void setCurrentChargePerKilobyte(int currentChargePerKilobyte) {
        this.currentChargePerKilobyte = currentChargePerKilobyte;
    }

    /**
     * This method sets a nextChargePerKilobyte.
     */ 
    public void setNextChargePerKilobyte(int nextChargePerKilobyte) {
        this.nextChargePerKilobyte = nextChargePerKilobyte;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof ChargePerVolume)) {
            return false;
        } 
        ChargePerVolume chargePerVolume = (ChargePerVolume) o;
        if(!(this.initialCharge == chargePerVolume.initialCharge)) {
            return false;
        }
        if(!(this.currentChargePerKilobyte == chargePerVolume.currentChargePerKilobyte)) {
            return false;
        }
        if(!(this.nextChargePerKilobyte == chargePerVolume.nextChargePerKilobyte)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // ChargePerVolume

