//Source file: DataSession.java
//Date: September 2004
//Data Session Control Interfaces and Data Types for 3GPP TS 29.198-08 V5.7.0

package org.csapi.jr.se.dsc;

/**
 * This interface represents a DataSession.<BR>
 *
 */
public interface DataSession extends org.csapi.jr.se.Service {

    /**
     * Adds a DataSessionListener which is interested in events generated by the DataSession.
     *
     * @param  dataSessionListener  A reference to the DataSessionListener which is to be added as
     *         a listener.
     */
    void addDataSessionListener(org.csapi.jr.se.dsc.DataSessionListener dataSessionListener);

    /**
     * Removes a DataSessionListener which is no longer interested in events generated by the DataSession.
     *
     * @param  dataSessionListener  A reference to the DataSessionListener which is to be removed as
     *         a listener.
     */
    void removeDataSessionListener(org.csapi.jr.se.dsc.DataSessionListener dataSessionListener);

    /**
     * Returns a reference to the DataSessionControlManager responsible for creation of the DataSession.
     *
     * @return  A reference to the DataSessionControlManager responsible for creation of the DataSession.
     */
    org.csapi.jr.se.dsc.DataSessionControlManager getDataSessionControlManager();

    /**
     * Invokes the release() method on the Parlay Gateway.
     */
    void release(
           org.csapi.jr.se.dsc.DataSessionReleaseCause cause)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidNetworkStateException;

    /**
     * Invokes the superviseDataSessionReq() method on the Parlay Gateway.
     */
    void superviseDataSessionReq(
           int                             treatment,
           org.csapi.jr.se.dsc.DataSessionSuperviseVolume bytes)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidNetworkStateException;

    /**
     * Invokes the setDataSessionChargePlan() method on the Parlay Gateway.
     */
    void setDataSessionChargePlan(
           org.csapi.jr.se.dsc.DataSessionChargePlan dataSessionChargePlan)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidNetworkStateException;

    /**
     * Invokes the setAdviceOfCharge() method on the Parlay Gateway.
     */
    void setAdviceOfCharge(
           org.csapi.jr.se.AoCInfo aoCInfo,
           int                             tariffSwitch)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidNetworkStateException,
       org.csapi.jr.se.InvalidTimeAndDateFormatException;

    /**
     * Invokes the deassignDataSession() method on the Parlay Gateway.
     */
    void deassignDataSession()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the continueProcessing() method on the Parlay Gateway.
     */
    void continueProcessing()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidNetworkStateException;

    /**
     * Creates a Connect object and returns a reference to the interface used to gain access
     * to it's methods.
     *
     * @return  A reference to the Connect interface.
     */
    org.csapi.jr.se.dsc.Connect createConnect();

}
