//Source file: DataSessionChargePlan.java
//Date: September 2004
//Data Session Control Interfaces and Data Types for 3GPP TS 29.198-08 V5.7.0

package org.csapi.jr.se.dsc;

/**
 * Defines the Sequence of Data Elements that specify the charge plan for the call.
Valid Currencies are:
ADP, AED, AFA, ALL, AMD, ANG, AON, AOR, ARS, ATS, AUD, AWG, AZM, BAM, 
BBD, BDT, BEF, BGL, BGN, BHD, BIF, BMD, BND, BOB, BOV, BRL, BSD, BTN, 
BWP, BYB, BZD, CAD, CDF, CHF, CLF, CLP, CNY, COP, CRC, CUP, CVE, CYP, 
CZK, DEM, DJF, DKK, DOP, DZD, ECS, ECV, EEK, EGP, ERN, ESP, ETB, EUR, 
FIM, FJD, FKP, FRF, GBP, GEL, GHC, GIP, GMD, GNF, GRD, GTQ, GWP, GYD, 
HKD, HNL, HRK, HTG, HUF, IDR, IEP, ILS, INR, IQD, IRR, ISK, ITL, JMD, 
JOD, JPY, KES, KGS, KHR, KMF, KPW, KRW, KWD, KYD, KZT, LAK, LBP, LKR, 
LRD, LSL, LTL, LUF, LVL, LYD, MAD, MDL, MGF, MKD, MMK, MNT, MOP, MRO, 
MTL, MUR, MVR, MWK, MXN, MXV, MYR, MZM, NAD, NGN, NIO, NLG, NOK, NPR, 
NZD, OMR, PAB, PEN, PGK, PHP, PKR, PLN, PTE, PYG, QAR, ROL, RUB, RUR, 
RWF, SAR, SBD, SCR, SDD, SEK, SGD, SHP, SIT, SKK, SLL, SOS, SRG, STD, 
SVC, SYP, SZL, THB, TJR, TMM, TND, TOP, TPE, TRL, TTD, TWD, TZS, UAH, 
UGX, USD, USN, USS, UYU, UZS, VEB, VND, VUV, WST, XAF, XAG, XAU, XBA, 
XBB, XBC, XBD, XCD, XDR, XFO, XFU, XOF, XPD, XPF, XPT, XTS, XXX, YER, 
YUM, ZAL, ZAR, ZMK, ZRN, ZWD.
XXX is used for transactions where no currency is involved. 
 * 
 */
public final class DataSessionChargePlan implements java.io.Serializable {

    private org.csapi.jr.se.dsc.DataSessionChargeOrder chargeOrderType;
    private String currency;
    private String additionalInfo;

    /**
     * Creates a new DataSessionChargePlan instance.
     */
    public DataSessionChargePlan () {}

    /**
     * Creates a new DataSessionChargePlan instance.
     * @param _chargeOrderType   Charge order
     * @param _currency   Currency unit according to ISO 4217: 1995
     * @param _additionalInfo   Descriptive string which is sent to the billing system without prior evaluation. Could be included in the ticket.
     */
    public DataSessionChargePlan (org.csapi.jr.se.dsc.DataSessionChargeOrder _chargeOrderType, String _currency, String _additionalInfo) {

        this.chargeOrderType = _chargeOrderType;
        this.currency = _currency;
        this.additionalInfo = _additionalInfo;
    }

    /**
     * This method returns a chargeOrderType.
     * 
     * @return a org.csapi.jr.se.dsc.DataSessionChargeOrder value
     */
    public org.csapi.jr.se.dsc.DataSessionChargeOrder getChargeOrderType() {
        return chargeOrderType;
    }

    /**
     * This method returns a currency.
     * 
     * @return a String value
     */
    public String getCurrency() {
        return currency;
    }

    /**
     * This method returns a additionalInfo.
     * 
     * @return a String value
     */
    public String getAdditionalInfo() {
        return additionalInfo;
    }


    /**
     * This method sets a chargeOrderType.
     */ 
    public void setChargeOrderType(org.csapi.jr.se.dsc.DataSessionChargeOrder chargeOrderType) {
        this.chargeOrderType = chargeOrderType;
    }

    /**
     * This method sets a currency.
     */ 
    public void setCurrency(String currency) {
        this.currency = currency;
    }

    /**
     * This method sets a additionalInfo.
     */ 
    public void setAdditionalInfo(String additionalInfo) {
        this.additionalInfo = additionalInfo;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof DataSessionChargePlan)) {
            return false;
        } 
        DataSessionChargePlan dataSessionChargePlan = (DataSessionChargePlan) o;
        if ((this.chargeOrderType != null) && (dataSessionChargePlan.chargeOrderType != null)) {
            if(!(this.chargeOrderType.equals(dataSessionChargePlan.chargeOrderType))) {
                return false;
            }
        }
        if ((this.currency != null) && (dataSessionChargePlan.currency != null)) {
            if(!(this.currency.equals(dataSessionChargePlan.currency)))  {
                return false;
            }
        }
        if ((this.additionalInfo != null) && (dataSessionChargePlan.additionalInfo != null)) {
            if(!(this.additionalInfo.equals(dataSessionChargePlan.additionalInfo)))  {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // DataSessionChargePlan

