//Source file: DataSessionErrorType.java
//Date: September 2004
//Data Session Control Interfaces and Data Types for 3GPP TS 29.198-08 V5.7.0

package org.csapi.jr.se.dsc;

/**
 * Defines a specific Data Session error.
 *
 */
public final class DataSessionErrorType implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static DataSessionErrorType[] _array = new DataSessionErrorType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private DataSessionErrorType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined; the method failed or was refused, but no specific reason can be given.
     */
    public static final int _DATA_SESSION_ERROR_UNDEFINED =  0;

    /**
     * Undefined; the method failed or was refused, but no specific reason can be given.
     */
    public static final DataSessionErrorType DATA_SESSION_ERROR_UNDEFINED = new DataSessionErrorType(_DATA_SESSION_ERROR_UNDEFINED);

    /**
     * The operation failed because an invalid address was given.
     */
    public static final int _DATA_SESSION_ERROR_INVALID_ADDRESS =  1;

    /**
     * The operation failed because an invalid address was given.
     */
    public static final DataSessionErrorType DATA_SESSION_ERROR_INVALID_ADDRESS = new DataSessionErrorType(_DATA_SESSION_ERROR_INVALID_ADDRESS);

    /**
     * The data session was not in a valid state for the requested operation.
     */
    public static final int _DATA_SESSION_ERROR_INVALID_STATE =  2;

    /**
     * The data session was not in a valid state for the requested operation.
     */
    public static final DataSessionErrorType DATA_SESSION_ERROR_INVALID_STATE = new DataSessionErrorType(_DATA_SESSION_ERROR_INVALID_STATE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved DataSessionErrorType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the DataSessionErrorType object
     */
    public String getValueText() {
        switch (_value) {
            case _DATA_SESSION_ERROR_UNDEFINED:
                return "DATA_SESSION_ERROR_UNDEFINED";
            case _DATA_SESSION_ERROR_INVALID_ADDRESS:
                return "DATA_SESSION_ERROR_INVALID_ADDRESS";
            case _DATA_SESSION_ERROR_INVALID_STATE:
                return "DATA_SESSION_ERROR_INVALID_STATE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static DataSessionErrorType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof DataSessionErrorType)) {
            return false;
        }
        DataSessionErrorType dataSessionErrorType = (DataSessionErrorType) o; 
        if(!(this.getValue() == dataSessionErrorType.getValue())) {
            return false;
        }
        if (this.hashCode() != dataSessionErrorType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // DataSessionErrorType

