//Source file: DataSessionEventCriteria.java
//Date: September 2004
//Data Session Control Interfaces and Data Types for 3GPP TS 29.198-08 V5.7.0

package org.csapi.jr.se.dsc;

/**
 * Defines the Sequence of Data Elements that specify the criteria for an event notification.
Of the addresses only the Plan and the AddrString are used for the purpose of matching the notifications against the criteria.
 * 
 */
public final class DataSessionEventCriteria implements java.io.Serializable {

    private org.csapi.jr.se.AddressRange destinationAddress;
    private org.csapi.jr.se.AddressRange originationAddress;
    private int dataSessionEventName;
    private org.csapi.jr.se.dsc.DataSessionMonitorMode monitorMode;

    /**
     * Creates a new DataSessionEventCriteria instance.
     */
    public DataSessionEventCriteria () {}

    /**
     * Creates a new DataSessionEventCriteria instance.
     * @param _destinationAddress   Defines the destination address for which the notification is reported.
     * @param _originationAddress   Defines the origination address or an address range for which the notification is requested.
     * @param _dataSessionEventName   Name of the event(s)
     * @param _monitorMode   Defines the mode that the Data Session is in following the notification. Monitor mode P_DATA_SESSION_MONITOR_MODE_DO_NOT_MONITOR is not a legal value here.
     */
    public DataSessionEventCriteria (org.csapi.jr.se.AddressRange _destinationAddress, org.csapi.jr.se.AddressRange _originationAddress, int _dataSessionEventName, org.csapi.jr.se.dsc.DataSessionMonitorMode _monitorMode) {

        this.destinationAddress = _destinationAddress;
        this.originationAddress = _originationAddress;
        this.dataSessionEventName = _dataSessionEventName;
        this.monitorMode = _monitorMode;
    }

    /**
     * This method returns a destinationAddress.
     * 
     * @return a org.csapi.jr.se.AddressRange value
     */
    public org.csapi.jr.se.AddressRange getDestinationAddress() {
        return destinationAddress;
    }

    /**
     * This method returns a originationAddress.
     * 
     * @return a org.csapi.jr.se.AddressRange value
     */
    public org.csapi.jr.se.AddressRange getOriginationAddress() {
        return originationAddress;
    }

    /**
     * This method returns a dataSessionEventName.
     * 
     * @return a int value
     */
    public int getDataSessionEventName() {
        return dataSessionEventName;
    }

    /**
     * This method returns a monitorMode.
     * 
     * @return a org.csapi.jr.se.dsc.DataSessionMonitorMode value
     */
    public org.csapi.jr.se.dsc.DataSessionMonitorMode getMonitorMode() {
        return monitorMode;
    }


    /**
     * This method sets a destinationAddress.
     */ 
    public void setDestinationAddress(org.csapi.jr.se.AddressRange destinationAddress) {
        this.destinationAddress = destinationAddress;
    }

    /**
     * This method sets a originationAddress.
     */ 
    public void setOriginationAddress(org.csapi.jr.se.AddressRange originationAddress) {
        this.originationAddress = originationAddress;
    }

    /**
     * This method sets a dataSessionEventName.
     */ 
    public void setDataSessionEventName(int dataSessionEventName) {
        this.dataSessionEventName = dataSessionEventName;
    }

    /**
     * This method sets a monitorMode.
     */ 
    public void setMonitorMode(org.csapi.jr.se.dsc.DataSessionMonitorMode monitorMode) {
        this.monitorMode = monitorMode;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof DataSessionEventCriteria)) {
            return false;
        } 
        DataSessionEventCriteria dataSessionEventCriteria = (DataSessionEventCriteria) o;
        if ((this.destinationAddress != null) && (dataSessionEventCriteria.destinationAddress != null)) {
            if(!(this.destinationAddress.equals(dataSessionEventCriteria.destinationAddress))) {
                return false;
            }
        }
        if ((this.originationAddress != null) && (dataSessionEventCriteria.originationAddress != null)) {
            if(!(this.originationAddress.equals(dataSessionEventCriteria.originationAddress))) {
                return false;
            }
        }
        if(!(this.dataSessionEventName == dataSessionEventCriteria.dataSessionEventName))  {
            return false;
        }
        if ((this.monitorMode != null) && (dataSessionEventCriteria.monitorMode != null)) {
            if(!(this.monitorMode.equals(dataSessionEventCriteria.monitorMode))) {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // DataSessionEventCriteria

