//Source file: DataSessionEventInfo.java
//Date: September 2004
//Data Session Control Interfaces and Data Types for 3GPP TS 29.198-08 V5.7.0

package org.csapi.jr.se.dsc;

/**
 * Defines the Sequence of Data Elements that specify the information returned to the application in a Data Session event notification.
 * 
 */
public final class DataSessionEventInfo implements java.io.Serializable {

    private org.csapi.jr.se.Address destinationAddress;
    private org.csapi.jr.se.Address originatingAddress;
    private int dataSessionEventName;
    private org.csapi.jr.se.dsc.DataSessionMonitorMode monitorMode;
    private org.csapi.jr.se.DataSessionQosClass qoSClass;

    /**
     * Creates a new DataSessionEventInfo instance.
     */
    public DataSessionEventInfo () {}

    /**
     * Creates a new DataSessionEventInfo instance.
     * @param _destinationAddress   Defines the destination address for which the notification is reported.
     * @param _originatingAddress   Defines the origination address for which the notification is reported.
     * @param _dataSessionEventName   Name of the event(s)
     * @param _monitorMode   Defines the mode in which the Data Session is reporting the notification.
Monitor mode P_DATA_SESSION_MONITOR_MODE_DO_NOT_MONITOR is not a legal value here.
     * @param _qoSClass   Defines the Quality of Service (QoS) class for the Data Session. QoSClass NULL is not a legal value when DataSessionEventName is set to P_EVENT_DSCS_QOS_CHANGED. For this particular event, the QoSClass defines the new QoS class effective after the change.
     */
    public DataSessionEventInfo (org.csapi.jr.se.Address _destinationAddress, org.csapi.jr.se.Address _originatingAddress, int _dataSessionEventName, org.csapi.jr.se.dsc.DataSessionMonitorMode _monitorMode, org.csapi.jr.se.DataSessionQosClass _qoSClass) {

        this.destinationAddress = _destinationAddress;
        this.originatingAddress = _originatingAddress;
        this.dataSessionEventName = _dataSessionEventName;
        this.monitorMode = _monitorMode;
        this.qoSClass = _qoSClass;
    }

    /**
     * This method returns a destinationAddress.
     * 
     * @return a org.csapi.jr.se.Address value
     */
    public org.csapi.jr.se.Address getDestinationAddress() {
        return destinationAddress;
    }

    /**
     * This method returns a originatingAddress.
     * 
     * @return a org.csapi.jr.se.Address value
     */
    public org.csapi.jr.se.Address getOriginatingAddress() {
        return originatingAddress;
    }

    /**
     * This method returns a dataSessionEventName.
     * 
     * @return a int value
     */
    public int getDataSessionEventName() {
        return dataSessionEventName;
    }

    /**
     * This method returns a monitorMode.
     * 
     * @return a org.csapi.jr.se.dsc.DataSessionMonitorMode value
     */
    public org.csapi.jr.se.dsc.DataSessionMonitorMode getMonitorMode() {
        return monitorMode;
    }

    /**
     * This method returns a qoSClass.
     * 
     * @return a org.csapi.jr.se.DataSessionQosClass value
     */
    public org.csapi.jr.se.DataSessionQosClass getQoSClass() {
        return qoSClass;
    }


    /**
     * This method sets a destinationAddress.
     */ 
    public void setDestinationAddress(org.csapi.jr.se.Address destinationAddress) {
        this.destinationAddress = destinationAddress;
    }

    /**
     * This method sets a originatingAddress.
     */ 
    public void setOriginatingAddress(org.csapi.jr.se.Address originatingAddress) {
        this.originatingAddress = originatingAddress;
    }

    /**
     * This method sets a dataSessionEventName.
     */ 
    public void setDataSessionEventName(int dataSessionEventName) {
        this.dataSessionEventName = dataSessionEventName;
    }

    /**
     * This method sets a monitorMode.
     */ 
    public void setMonitorMode(org.csapi.jr.se.dsc.DataSessionMonitorMode monitorMode) {
        this.monitorMode = monitorMode;
    }

    /**
     * This method sets a qoSClass.
     */ 
    public void setQoSClass(org.csapi.jr.se.DataSessionQosClass qoSClass) {
        this.qoSClass = qoSClass;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof DataSessionEventInfo)) {
            return false;
        } 
        DataSessionEventInfo dataSessionEventInfo = (DataSessionEventInfo) o;
        if ((this.destinationAddress != null) && (dataSessionEventInfo.destinationAddress != null)) {
            if(!(this.destinationAddress.equals(dataSessionEventInfo.destinationAddress))) {
                return false;
            }
        }
        if ((this.originatingAddress != null) && (dataSessionEventInfo.originatingAddress != null)) {
            if(!(this.originatingAddress.equals(dataSessionEventInfo.originatingAddress))) {
                return false;
            }
        }
        if(!(this.dataSessionEventName == dataSessionEventInfo.dataSessionEventName))  {
            return false;
        }
        if ((this.monitorMode != null) && (dataSessionEventInfo.monitorMode != null)) {
            if(!(this.monitorMode.equals(dataSessionEventInfo.monitorMode))) {
                return false;
            }
        }
        if ((this.qoSClass != null) && (dataSessionEventInfo.qoSClass != null)) {
            if(!(this.qoSClass.equals(dataSessionEventInfo.qoSClass))) {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // DataSessionEventInfo

