//Source file: DataSessionFault.java
//Date: September 2004
//Data Session Control Interfaces and Data Types for 3GPP TS 29.198-08 V5.7.0

package org.csapi.jr.se.dsc;

/**
 * Defines the cause of the data session fault detected.
 *
 */
public final class DataSessionFault implements java.io.Serializable {

    private int _value;
    private static int _size = 4;
    private static DataSessionFault[] _array = new DataSessionFault[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private DataSessionFault(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined.
     */
    public static final int _DATA_SESSION_FAULT_UNDEFINED =  0;

    /**
     * Undefined.
     */
    public static final DataSessionFault DATA_SESSION_FAULT_UNDEFINED = new DataSessionFault(_DATA_SESSION_FAULT_UNDEFINED);

    /**
     * User has finalised the data session before any message could be sent by the application.
     */
    public static final int _DATA_SESSION_FAULT_USER_ABORTED =  1;

    /**
     * User has finalised the data session before any message could be sent by the application.
     */
    public static final DataSessionFault DATA_SESSION_FAULT_USER_ABORTED = new DataSessionFault(_DATA_SESSION_FAULT_USER_ABORTED);

    /**
     * This fault occurs when the final report has been sent to the application, but the application did not explicitly release data session object, within a specified time.
The timer value is operator specific.
     */
    public static final int _DATA_SESSION_TIMEOUT_ON_RELEASE =  2;

    /**
     * This fault occurs when the final report has been sent to the application, but the application did not explicitly release data session object, within a specified time.
The timer value is operator specific.
     */
    public static final DataSessionFault DATA_SESSION_TIMEOUT_ON_RELEASE = new DataSessionFault(_DATA_SESSION_TIMEOUT_ON_RELEASE);

    /**
     * This fault occurs when the application did not instruct the gateway how to handle the call within a specified time, after the gateway reported an event that was requested by the application in interrupt mode.
The timer value is operator specific.
     */
    public static final int _DATA_SESSION_TIMEOUT_ON_INTERRUPT =  3;

    /**
     * This fault occurs when the application did not instruct the gateway how to handle the call within a specified time, after the gateway reported an event that was requested by the application in interrupt mode.
The timer value is operator specific.
     */
    public static final DataSessionFault DATA_SESSION_TIMEOUT_ON_INTERRUPT = new DataSessionFault(_DATA_SESSION_TIMEOUT_ON_INTERRUPT);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved DataSessionFault object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the DataSessionFault object
     */
    public String getValueText() {
        switch (_value) {
            case _DATA_SESSION_FAULT_UNDEFINED:
                return "DATA_SESSION_FAULT_UNDEFINED";
            case _DATA_SESSION_FAULT_USER_ABORTED:
                return "DATA_SESSION_FAULT_USER_ABORTED";
            case _DATA_SESSION_TIMEOUT_ON_RELEASE:
                return "DATA_SESSION_TIMEOUT_ON_RELEASE";
            case _DATA_SESSION_TIMEOUT_ON_INTERRUPT:
                return "DATA_SESSION_TIMEOUT_ON_INTERRUPT";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 3
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static DataSessionFault getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof DataSessionFault)) {
            return false;
        }
        DataSessionFault dataSessionFault = (DataSessionFault) o; 
        if(!(this.getValue() == dataSessionFault.getValue())) {
            return false;
        }
        if (this.hashCode() != dataSessionFault.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // DataSessionFault

