//Source file: DataSessionMonitorMode.java
//Date: September 2004
//Data Session Control Interfaces and Data Types for 3GPP TS 29.198-08 V5.7.0

package org.csapi.jr.se.dsc;

/**
 * Defines the mode that the call will monitor for events, or the mode that the call is in following a detected event.
 *
 */
public final class DataSessionMonitorMode implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static DataSessionMonitorMode[] _array = new DataSessionMonitorMode[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private DataSessionMonitorMode(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * The data session event is intercepted by the data session control service and data session establishment is interrupted. The application is notified of the event and data session establishment resumes following an appropriate API call or network event (such as a data session release).
     */
    public static final int _DATA_SESSION_MONITOR_MODE_INTERRUPT =  0;

    /**
     * The data session event is intercepted by the data session control service and data session establishment is interrupted. The application is notified of the event and data session establishment resumes following an appropriate API call or network event (such as a data session release).
     */
    public static final DataSessionMonitorMode DATA_SESSION_MONITOR_MODE_INTERRUPT = new DataSessionMonitorMode(_DATA_SESSION_MONITOR_MODE_INTERRUPT);

    /**
     * The data session event is detected by the data session control service but not intercepted. The application is notified of the event and data session establishment continues.
     */
    public static final int _DATA_SESSION_MONITOR_MODE_NOTIFY =  1;

    /**
     * The data session event is detected by the data session control service but not intercepted. The application is notified of the event and data session establishment continues.
     */
    public static final DataSessionMonitorMode DATA_SESSION_MONITOR_MODE_NOTIFY = new DataSessionMonitorMode(_DATA_SESSION_MONITOR_MODE_NOTIFY);

    /**
     * Do not monitor for the event.
     */
    public static final int _DATA_SESSION_MONITOR_MODE_DO_NOT_MONITOR =  2;

    /**
     * Do not monitor for the event.
     */
    public static final DataSessionMonitorMode DATA_SESSION_MONITOR_MODE_DO_NOT_MONITOR = new DataSessionMonitorMode(_DATA_SESSION_MONITOR_MODE_DO_NOT_MONITOR);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved DataSessionMonitorMode object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the DataSessionMonitorMode object
     */
    public String getValueText() {
        switch (_value) {
            case _DATA_SESSION_MONITOR_MODE_INTERRUPT:
                return "DATA_SESSION_MONITOR_MODE_INTERRUPT";
            case _DATA_SESSION_MONITOR_MODE_NOTIFY:
                return "DATA_SESSION_MONITOR_MODE_NOTIFY";
            case _DATA_SESSION_MONITOR_MODE_DO_NOT_MONITOR:
                return "DATA_SESSION_MONITOR_MODE_DO_NOT_MONITOR";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static DataSessionMonitorMode getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof DataSessionMonitorMode)) {
            return false;
        }
        DataSessionMonitorMode dataSessionMonitorMode = (DataSessionMonitorMode) o; 
        if(!(this.getValue() == dataSessionMonitorMode.getValue())) {
            return false;
        }
        if (this.hashCode() != dataSessionMonitorMode.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // DataSessionMonitorMode

