//Source file: DataSessionReportType.java
//Date: September 2004
//Data Session Control Interfaces and Data Types for 3GPP TS 29.198-08 V5.7.0

package org.csapi.jr.se.dsc;

/**
 * Defines a specific data session event report type.
 *
 */
public final class DataSessionReportType implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static DataSessionReportType[] _array = new DataSessionReportType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private DataSessionReportType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined.
     */
    public static final int _DATA_SESSION_REPORT_UNDEFINED =  0;

    /**
     * Undefined.
     */
    public static final DataSessionReportType DATA_SESSION_REPORT_UNDEFINED = new DataSessionReportType(_DATA_SESSION_REPORT_UNDEFINED);

    /**
     * Data session established.
     */
    public static final int _DATA_SESSION_REPORT_CONNECTED =  1;

    /**
     * Data session established.
     */
    public static final DataSessionReportType DATA_SESSION_REPORT_CONNECTED = new DataSessionReportType(_DATA_SESSION_REPORT_CONNECTED);

    /**
     * Data session disconnect requested by data session party.
     */
    public static final int _DATA_SESSION_REPORT_DISCONNECT =  2;

    /**
     * Data session disconnect requested by data session party.
     */
    public static final DataSessionReportType DATA_SESSION_REPORT_DISCONNECT = new DataSessionReportType(_DATA_SESSION_REPORT_DISCONNECT);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved DataSessionReportType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the DataSessionReportType object
     */
    public String getValueText() {
        switch (_value) {
            case _DATA_SESSION_REPORT_UNDEFINED:
                return "DATA_SESSION_REPORT_UNDEFINED";
            case _DATA_SESSION_REPORT_CONNECTED:
                return "DATA_SESSION_REPORT_CONNECTED";
            case _DATA_SESSION_REPORT_DISCONNECT:
                return "DATA_SESSION_REPORT_DISCONNECT";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static DataSessionReportType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof DataSessionReportType)) {
            return false;
        }
        DataSessionReportType dataSessionReportType = (DataSessionReportType) o; 
        if(!(this.getValue() == dataSessionReportType.getValue())) {
            return false;
        }
        if (this.hashCode() != dataSessionReportType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // DataSessionReportType

