//Source file: DataSessionSuperviseVolume.java
//Date: September 2004
//Data Session Control Interfaces and Data Types for 3GPP TS 29.198-08 V5.7.0

package org.csapi.jr.se.dsc;

/**
 * Defines the Sequence of Data Elements that specify the amount of volume that is allowed to be transmitted for the specific connection.
 * 
 */
public final class DataSessionSuperviseVolume implements java.io.Serializable {

    private int volumeQuantity;
    private int volumeUnit;

    /**
     * Creates a new DataSessionSuperviseVolume instance.
     */
    public DataSessionSuperviseVolume () {}

    /**
     * Creates a new DataSessionSuperviseVolume instance.
     * @param _volumeQuantity   This data type is identical to a TpInt32, and defines the quantity of the granted volume that can be transmitted for the specific connection. The volume specifies the sum of uplink and downlink transfer data volumes.
     * @param _volumeUnit   In Order to enlarge the range of the volume quantity value the exponent of a scaling factor (10^VolumeUnit) is provided.
When the unit is for example in kilobytes, VolumeUnit shall be set to 3.
     */
    public DataSessionSuperviseVolume (int _volumeQuantity, int _volumeUnit) {

        this.volumeQuantity = _volumeQuantity;
        this.volumeUnit = _volumeUnit;
    }

    /**
     * This method returns a volumeQuantity.
     * 
     * @return a int value
     */
    public int getVolumeQuantity() {
        return volumeQuantity;
    }

    /**
     * This method returns a volumeUnit.
     * 
     * @return a int value
     */
    public int getVolumeUnit() {
        return volumeUnit;
    }


    /**
     * This method sets a volumeQuantity.
     */ 
    public void setVolumeQuantity(int volumeQuantity) {
        this.volumeQuantity = volumeQuantity;
    }

    /**
     * This method sets a volumeUnit.
     */ 
    public void setVolumeUnit(int volumeUnit) {
        this.volumeUnit = volumeUnit;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof DataSessionSuperviseVolume)) {
            return false;
        } 
        DataSessionSuperviseVolume dataSessionSuperviseVolume = (DataSessionSuperviseVolume) o;
        if(!(this.volumeQuantity == dataSessionSuperviseVolume.volumeQuantity)) {
            return false;
        }
        if(!(this.volumeUnit == dataSessionSuperviseVolume.volumeUnit)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // DataSessionSuperviseVolume

